@@ -2,7 +2,7 @@ from django import forms
 from django.core.files import File
 from django.conf import settings
 
-import widgets
+from .widgets import FPFileWidget
 import urllib2
 try:
     from cStringIO import StringIO
@@ -10,13 +10,13 @@ except ImportError:
     from StringIO import StringIO
 
 
-class FPFileField(forms.FileField):
-    widget = widgets.FPFileWidget
+class FPFieldMixin():
+    widget = FPFileWidget
     default_mimetypes = "*/*"
 
-    def __init__(self, *args, **kwargs):
+    def initialize(self, *args, **kwargs):
         """
-        Initializes the Filepicker file field.
+        Initializes the Filepicker field.
         Valid arguments:
         * apikey. This string is required if it isn't set as settings.FILEPICKER_API_KEY
         * mimetypes. Optional, the allowed mimetypes for files. Defaults to "*/*" (all files)
@@ -42,8 +42,6 @@ class FPFileField(forms.FileField):
 
         self.services = kwargs.pop('services', getattr(settings, 'FILEPICKER_SERVICES', None))
 
-        super(FPFileField, self).__init__(*args, **kwargs)
-
     def widget_attrs(self, widget):
         attrs = {
                 'data-fp-apikey': self.apikey,
@@ -55,6 +53,35 @@ class FPFileField(forms.FileField):
 
         return attrs
 
+
+class FPUrlField(FPFieldMixin, forms.URLField):
+    widget = FPFileWidget
+    default_mimetypes = "*/*"
+
+    def __init__(self, *args, **kwargs):
+        """
+        Initializes the Filepicker url field.
+        Valid arguments:
+        * apikey. This string is required if it isn't set as settings.FILEPICKER_API_KEY
+        * mimetypes. Optional, the allowed mimetypes for files. Defaults to "*/*" (all files)
+        * services. Optional, the allowed services to pull from.
+        """
+        self.initialize(*args, **kwargs)
+        super(FPUrlField, self).__init__(*args, **kwargs)
+
+
+class FPFileField(FPFieldMixin, forms.FileField):
+    def __init__(self, *args, **kwargs):
+        """
+        Initializes the Filepicker url field.
+        Valid arguments:
+        * apikey. This string is required if it isn't set as settings.FILEPICKER_API_KEY
+        * mimetypes. Optional, the allowed mimetypes for files. Defaults to "*/*" (all files)
+        * services. Optional, the allowed services to pull from.
+        """
+        self.initialize(*args, **kwargs)
+        super(FPFileField, self).__init__(*args, **kwargs)
+
     def to_python(self, data):
         """Takes the url in data and creates a File object"""
         if not data or not data.startswith('http'):
